@@ -27,11 +27,11 @@
 #include <iostream>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/rendering.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/rendering.hh>
 #include "GlutWindow.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -118,12 +118,20 @@ int main(int _argc, char** _argv)
 {
   glutInit(&_argc, _argv);
 
+  // Expose engine name to command line because we can't instantiate both
+  // ogre and ogre2 at the same time
+  std::string ogreEngineName("ogre");
+  if (_argc > 1)
+  {
+    ogreEngineName = _argv[1];
+  }
+
   common::Console::SetVerbosity(4);
   std::vector<std::string> engineNames;
   std::vector<CameraPtr> cameras;
   std::vector<NodePtr> nodes;
 
-  engineNames.push_back("ogre");
+  engineNames.push_back(ogreEngineName);
   engineNames.push_back("optix");
 
   for (auto engineName : engineNames)
