@@ -27,12 +27,12 @@
 #include <iostream>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/rendering.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/rendering.hh>
 
 #include "GlutWindow.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -152,7 +152,7 @@ CameraPtr createCamera(const std::string &_engineName)
 
   SensorPtr sensor = scene->SensorByName("camera");
 
-  // get render pass system
+  //! [get render pass system]
   CameraPtr camera = std::dynamic_pointer_cast<Camera>(sensor);
   RenderPassSystemPtr rpSystem = engine->RenderPassSystem();
   if (rpSystem)
@@ -165,6 +165,7 @@ CameraPtr createCamera(const std::string &_engineName)
     noisePass->SetStdDev(0.08);
     camera->AddRenderPass(noisePass);
   }
+  //! [get render pass system]
 
   // return camera sensor
   return camera;
@@ -175,11 +176,19 @@ int main(int _argc, char** _argv)
 {
   glutInit(&_argc, _argv);
 
+  // Expose engine name to command line because we can't instantiate both
+  // ogre and ogre2 at the same time
+  std::string ogreEngineName("ogre");
+  if (_argc > 1)
+  {
+    ogreEngineName = _argv[1];
+  }
+
   common::Console::SetVerbosity(4);
   std::vector<std::string> engineNames;
   std::vector<CameraPtr> cameras;
 
-  engineNames.push_back("ogre");
+  engineNames.push_back(ogreEngineName);
   engineNames.push_back("optix");
   for (auto engineName : engineNames)
   {
