@@ -27,14 +27,14 @@
 #include <iostream>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/common/MeshManager.hh>
-#include <gz/rendering.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/MeshManager.hh>
+#include <ignition/rendering.hh>
 
 #include "example_config.hh"
 #include "GlutWindow.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 const std::string RESOURCE_PATH =
@@ -129,11 +129,19 @@ int main(int _argc, char** _argv)
 {
   glutInit(&_argc, _argv);
 
+  // Expose engine name to command line because we can't instantiate both
+  // ogre and ogre2 at the same time
+  std::string ogreEngineName("ogre");
+  if (_argc > 1)
+  {
+    ogreEngineName = _argv[1];
+  }
+
   common::Console::SetVerbosity(4);
   std::vector<std::string> engineNames;
   std::vector<CameraPtr> cameras;
 
-  engineNames.push_back("ogre2");
+  engineNames.push_back(ogreEngineName);
 
   for (auto engineName : engineNames)
   {
