@@ -15,15 +15,16 @@
  *
  */
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
-#include "gz/rendering/ogre/OgreDynamicLines.hh"
-#include "gz/rendering/ogre/OgreMarker.hh"
-#include "gz/rendering/ogre/OgreMaterial.hh"
-#include "gz/rendering/ogre/OgreMesh.hh"
-#include "gz/rendering/ogre/OgreScene.hh"
+#include "ignition/rendering/ogre/OgreCapsule.hh"
+#include "ignition/rendering/ogre/OgreDynamicLines.hh"
+#include "ignition/rendering/ogre/OgreMarker.hh"
+#include "ignition/rendering/ogre/OgreMaterial.hh"
+#include "ignition/rendering/ogre/OgreMesh.hh"
+#include "ignition/rendering/ogre/OgreScene.hh"
 
-class gz::rendering::OgreMarkerPrivate
+class ignition::rendering::OgreMarkerPrivate
 {
   /// \brief Marker material
   public: OgreMaterialPtr material = nullptr;
@@ -31,11 +32,11 @@ class gz::rendering::OgreMarkerPrivate
   /// \brief DynamicLines Object to display
   public: std::shared_ptr<OgreDynamicLines> dynamicRenderable;
 
-  /// \brief Mesh Object for primitive shapes
-  public: OgreMeshPtr mesh = nullptr;
+  /// \brief Geometry Object for primitive shapes
+  public: OgreGeometryPtr geom{nullptr};
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -59,10 +60,10 @@ void OgreMarker::PreRender()
 //////////////////////////////////////////////////
 void OgreMarker::Destroy()
 {
-  if (this->dataPtr->mesh)
+  if (this->dataPtr->geom)
   {
-    this->dataPtr->mesh->Destroy();
-    this->dataPtr->mesh.reset();
+    this->dataPtr->geom->Destroy();
+    this->dataPtr->geom.reset();
   }
 
   if (this->dataPtr->material && this->Scene())
@@ -76,14 +77,21 @@ void OgreMarker::Destroy()
 //////////////////////////////////////////////////
 Ogre::MovableObject *OgreMarker::OgreObject() const
 {
-  switch (markerType)
+  switch (this->markerType)
   {
     case MT_NONE:
       return nullptr;
     case MT_BOX:
+    case MT_CAPSULE:
     case MT_CYLINDER:
     case MT_SPHERE:
-      return this->dataPtr->mesh->OgreObject();
+    {
+      if (nullptr != this->dataPtr->geom)
+      {
+        return this->dataPtr->geom->OgreObject();
+      }
+      return nullptr;
+    }
     case MT_LINE_STRIP:
     case MT_LINE_LIST:
     case MT_POINTS:
@@ -93,7 +101,7 @@ Ogre::MovableObject *OgreMarker::OgreObject() const
       return std::dynamic_pointer_cast<Ogre::MovableObject>
         (this->dataPtr->dynamicRenderable).get();
     default:
-      ignerr << "Invalid Marker type " << markerType << "\n";
+      ignerr << "Invalid Marker type " << this->markerType << "\n";
       return nullptr;
   }
 }
@@ -110,16 +118,22 @@ void OgreMarker::Create()
   this->markerType = MT_NONE;
   this->dataPtr->dynamicRenderable.reset(new OgreDynamicLines(MT_LINE_STRIP));
 
-  if (!this->dataPtr->mesh)
+  if (!this->dataPtr->geom)
   {
-    this->dataPtr->mesh =
-      std::dynamic_pointer_cast<OgreMesh>(this->scene->CreateBox());
+    this->dataPtr->geom =
+      std::dynamic_pointer_cast<OgreGeometry>(this->scene->CreateBox());
   }
 }
 
 //////////////////////////////////////////////////
 void OgreMarker::SetMaterial(MaterialPtr _material, bool _unique)
 {
+  if (nullptr == _material)
+  {
+    ignerr << "Cannot assign null material" << std::endl;
+    return;
+  }
+
   _material = (_unique) ? _material->Clone() : _material;
 
   OgreMaterialPtr derived =
@@ -145,10 +159,20 @@ void OgreMarker::SetMaterial(MaterialPtr _material, bool _unique)
     case MT_NONE:
       break;
     case MT_BOX:
+    case MT_CAPSULE:
     case MT_CYLINDER:
     case MT_SPHERE:
-      this->dataPtr->mesh->SetMaterial(derived, false);
+    {
+      if (nullptr != this->dataPtr->geom)
+      {
+        this->dataPtr->geom->SetMaterial(derived, false);
+      }
+      else
+      {
+        ignerr << "Failed to set material, null geometry." << std::endl;
+      }
       break;
+    }
     case MT_LINE_STRIP:
     case MT_LINE_LIST:
     case MT_POINTS:
@@ -175,14 +199,14 @@ MaterialPtr OgreMarker::Material() const
 
 //////////////////////////////////////////////////
 void OgreMarker::SetPoint(unsigned int _index,
-    const math::Vector3d &_value)
+    const ignition::math::Vector3d &_value)
 {
   this->dataPtr->dynamicRenderable->SetPoint(_index, _value);
 }
 
 //////////////////////////////////////////////////
-void OgreMarker::AddPoint(const math::Vector3d &_pt,
-    const math::Color &_color)
+void OgreMarker::AddPoint(const ignition::math::Vector3d &_pt,
+    const ignition::math::Color &_color)
 {
   this->dataPtr->dynamicRenderable->AddPoint(_pt, _color);
 }
@@ -202,16 +226,20 @@ void OgreMarker::SetType(MarkerType _markerType)
     case MT_NONE:
       break;
     case MT_BOX:
-      this->dataPtr->mesh =
-        std::dynamic_pointer_cast<OgreMesh>(this->scene->CreateBox());
+      this->dataPtr->geom =
+        std::dynamic_pointer_cast<OgreGeometry>(this->scene->CreateBox());
+      break;
+    case MT_CAPSULE:
+      this->dataPtr->geom =
+        std::dynamic_pointer_cast<OgreGeometry>(this->scene->CreateCapsule());
       break;
     case MT_CYLINDER:
-      this->dataPtr->mesh =
-        std::dynamic_pointer_cast<OgreMesh>(this->scene->CreateCylinder());
+      this->dataPtr->geom =
+        std::dynamic_pointer_cast<OgreGeometry>(this->scene->CreateCylinder());
       break;
     case MT_SPHERE:
-      this->dataPtr->mesh =
-        std::dynamic_pointer_cast<OgreMesh>(this->scene->CreateSphere());
+      this->dataPtr->geom =
+        std::dynamic_pointer_cast<OgreGeometry>(this->scene->CreateSphere());
       break;
     case MT_LINE_STRIP:
     case MT_LINE_LIST:
