@@ -15,17 +15,17 @@
  *
  */
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
 
-#include "gz/rendering/ShaderParams.hh"
-#include "gz/rendering/ogre/OgreMaterial.hh"
-#include "gz/rendering/ogre/OgreConversions.hh"
-#include "gz/rendering/ogre/OgreRenderEngine.hh"
-#include "gz/rendering/ogre/OgreRTShaderSystem.hh"
-#include "gz/rendering/ogre/OgreScene.hh"
+#include "ignition/rendering/ShaderParams.hh"
+#include "ignition/rendering/ogre/OgreMaterial.hh"
+#include "ignition/rendering/ogre/OgreConversions.hh"
+#include "ignition/rendering/ogre/OgreRenderEngine.hh"
+#include "ignition/rendering/ogre/OgreRTShaderSystem.hh"
+#include "ignition/rendering/ogre/OgreScene.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -156,6 +156,19 @@ void OgreMaterial::SetEmissive(const math::Color &_color)
 #endif
 }
 
+//////////////////////////////////////////////////
+float OgreMaterial::RenderOrder() const
+{
+  return this->renderOrder;
+}
+
+//////////////////////////////////////////////////
+void OgreMaterial::SetRenderOrder(const float _renderOrder)
+{
+  this->renderOrder = _renderOrder;
+  this->ogrePass->setDepthBias(this->renderOrder);
+}
+
 //////////////////////////////////////////////////
 double OgreMaterial::Shininess() const
 {
@@ -337,7 +350,7 @@ void OgreMaterial::UpdateShaderParams()
 void OgreMaterial::UpdateShaderParams(ConstShaderParamsPtr _params,
     Ogre::GpuProgramParametersSharedPtr _ogreParams)
 {
-  for (const auto & name_param : *_params)
+  for (const auto name_param : *_params)
   {
     if (ShaderParam::PARAM_FLOAT == name_param.second.Type())
     {
@@ -351,6 +364,28 @@ void OgreMaterial::UpdateShaderParams(ConstShaderParamsPtr _params,
       name_param.second.Value(&value);
       _ogreParams->setNamedConstant(name_param.first, value);
     }
+    else if (ShaderParam::PARAM_FLOAT_BUFFER == name_param.second.Type())
+    {
+      std::shared_ptr<void> buffer;
+      name_param.second.Buffer(buffer);
+      uint32_t count = name_param.second.Count();
+
+      // multiple other than 4 is currently only supported by GLSL
+      uint32_t multiple = 1;
+      _ogreParams->setNamedConstant(name_param.first,
+          reinterpret_cast<float*>(buffer.get()), count, multiple);
+    }
+    else if (ShaderParam::PARAM_INT_BUFFER == name_param.second.Type())
+    {
+      std::shared_ptr<void> buffer;
+      name_param.second.Buffer(buffer);
+      uint32_t count = name_param.second.Count();
+
+      // multiple other than 4 is currently only supported by GLSL
+      uint32_t multiple = 1;
+      _ogreParams->setNamedConstant(name_param.first,
+        reinterpret_cast<int*>(buffer.get()), count, multiple);
+    }
   }
 }
 
@@ -548,13 +583,16 @@ void OgreMaterial::UpdateTransparency()
   Ogre::ColourValue color = this->ogrePass->getAmbient();
   double alpha = (1 - this->transparency) * color.a;
 
-  if (alpha < 1)
+  if (alpha < 1 || this->textureAlphaEnabled)
   {
     this->ogrePass->setDepthWriteEnabled(false);
     this->ogrePass->setSceneBlending(Ogre::SBT_TRANSPARENT_ALPHA);
 
-    this->ogreTexState->setAlphaOperation(Ogre::LBX_SOURCE1, Ogre::LBS_MANUAL,
-        Ogre::LBS_CURRENT, alpha);
+    if (!this->textureAlphaEnabled)
+    {
+      this->ogreTexState->setAlphaOperation(Ogre::LBX_SOURCE1, Ogre::LBS_MANUAL,
+          Ogre::LBS_CURRENT, alpha);
+    }
   }
   else
   {
@@ -562,6 +600,19 @@ void OgreMaterial::UpdateTransparency()
     this->ogrePass->setDepthCheckEnabled(true);
     this->ogrePass->setSceneBlending(Ogre::SBT_REPLACE);
   }
+  if (this->twoSidedEnabled)
+    this->ogrePass->setCullingMode(Ogre::CULL_NONE);
+  else
+    this->ogrePass->setCullingMode(Ogre::CULL_CLOCKWISE);
+}
+
+//////////////////////////////////////////////////
+void OgreMaterial::SetAlphaFromTexture(bool _enabled,
+  double _alpha, bool _twoSided)
+{
+  // TODO(anyone) Implement alpha testing for shadow caster pass
+  BaseMaterial::SetAlphaFromTexture(_enabled, _alpha, _twoSided);
+  this->UpdateTransparency();
 }
 
 //////////////////////////////////////////////////
