@@ -15,30 +15,36 @@
  *
  */
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
-#include "gz/rendering/ogre/OgreArrowVisual.hh"
-#include "gz/rendering/ogre/OgreAxisVisual.hh"
-#include "gz/rendering/ogre/OgreCamera.hh"
-#include "gz/rendering/ogre/OgreDepthCamera.hh"
-#include "gz/rendering/ogre/OgreConversions.hh"
-#include "gz/rendering/ogre/OgreGeometry.hh"
-#include "gz/rendering/ogre/OgreGizmoVisual.hh"
-#include "gz/rendering/ogre/OgreGpuRays.hh"
-#include "gz/rendering/ogre/OgreGrid.hh"
-#include "gz/rendering/ogre/OgreIncludes.hh"
-#include "gz/rendering/ogre/OgreText.hh"
-#include "gz/rendering/ogre/OgreMaterial.hh"
-#include "gz/rendering/ogre/OgreMarker.hh"
-#include "gz/rendering/ogre/OgreMeshFactory.hh"
-#include "gz/rendering/ogre/OgreRayQuery.hh"
-#include "gz/rendering/ogre/OgreRenderEngine.hh"
-#include "gz/rendering/ogre/OgreRenderTarget.hh"
-#include "gz/rendering/ogre/OgreRTShaderSystem.hh"
-#include "gz/rendering/ogre/OgreScene.hh"
-#include "gz/rendering/ogre/OgreStorage.hh"
-#include "gz/rendering/ogre/OgreThermalCamera.hh"
-#include "gz/rendering/ogre/OgreVisual.hh"
+#include "ignition/rendering/ogre/OgreArrowVisual.hh"
+#include "ignition/rendering/ogre/OgreAxisVisual.hh"
+#include "ignition/rendering/ogre/OgreCamera.hh"
+#include "ignition/rendering/ogre/OgreCapsule.hh"
+#include "ignition/rendering/ogre/OgreConversions.hh"
+#include "ignition/rendering/ogre/OgreDepthCamera.hh"
+#include "ignition/rendering/ogre/OgreGeometry.hh"
+#include "ignition/rendering/ogre/OgreGizmoVisual.hh"
+#include "ignition/rendering/ogre/OgreGpuRays.hh"
+#include "ignition/rendering/ogre/OgreGrid.hh"
+#include "ignition/rendering/ogre/OgreHeightmap.hh"
+#include "ignition/rendering/ogre/OgreIncludes.hh"
+#include "ignition/rendering/ogre/OgreLidarVisual.hh"
+#include "ignition/rendering/ogre/OgreLightVisual.hh"
+#include "ignition/rendering/ogre/OgreMarker.hh"
+#include "ignition/rendering/ogre/OgreMaterial.hh"
+#include "ignition/rendering/ogre/OgreMeshFactory.hh"
+#include "ignition/rendering/ogre/OgreParticleEmitter.hh"
+#include "ignition/rendering/ogre/OgreRTShaderSystem.hh"
+#include "ignition/rendering/ogre/OgreRayQuery.hh"
+#include "ignition/rendering/ogre/OgreRenderEngine.hh"
+#include "ignition/rendering/ogre/OgreRenderTarget.hh"
+#include "ignition/rendering/ogre/OgreScene.hh"
+#include "ignition/rendering/ogre/OgreStorage.hh"
+#include "ignition/rendering/ogre/OgreText.hh"
+#include "ignition/rendering/ogre/OgreThermalCamera.hh"
+#include "ignition/rendering/ogre/OgreVisual.hh"
+#include "ignition/rendering/ogre/OgreWireBox.hh"
 
 namespace ignition
 {
@@ -119,7 +125,7 @@ namespace ignition
   }
 }
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -243,7 +249,7 @@ void OgreScene::SetGradientBackgroundColor(
     return;
   }
 
-  // Convert the math::Color to Ogre::ColourValue.
+  // Convert the ignition::math::Color to Ogre::ColourValue.
   std::array<Ogre::ColourValue, 4> ogreColors;
   for (auto i = 0u; i < 4; ++i)
     ogreColors[i].setAsRGBA(_colors[i].AsRGBA());
@@ -363,6 +369,15 @@ PointLightPtr OgreScene::CreatePointLightImpl(unsigned int _id,
   return (result) ? light : nullptr;
 }
 
+//////////////////////////////////////////////////
+LightVisualPtr OgreScene::CreateLightVisualImpl(unsigned int _id,
+    const std::string &_name)
+{
+  OgreLightVisualPtr visual(new OgreLightVisual);
+  bool result = this->InitObject(visual, _id, _name);
+  return (result) ? visual : nullptr;
+}
+
 //////////////////////////////////////////////////
 SpotLightPtr OgreScene::CreateSpotLightImpl(unsigned int _id,
     const std::string &_name)
@@ -500,6 +515,25 @@ MeshPtr OgreScene::CreateMeshImpl(unsigned int _id, const std::string &_name,
   return (result) ? mesh : nullptr;
 }
 
+//////////////////////////////////////////////////
+CapsulePtr OgreScene::CreateCapsuleImpl(
+  unsigned int _id, const std::string &_name)
+{
+  OgreCapsulePtr capsule(new OgreCapsule);
+  bool result = this->InitObject(capsule, _id, _name);
+  return (result) ? capsule : nullptr;
+}
+
+//////////////////////////////////////////////////
+HeightmapPtr OgreScene::CreateHeightmapImpl(unsigned int _id,
+    const std::string &_name, const HeightmapDescriptor &_desc)
+{
+  OgreHeightmapPtr heightmap;
+  heightmap.reset(new OgreHeightmap(_desc));
+  bool result = this->InitObject(heightmap, _id, _name);
+  return (result) ? heightmap : nullptr;
+}
+
 //////////////////////////////////////////////////
 GridPtr OgreScene::CreateGridImpl(unsigned int _id, const std::string &_name)
 {
@@ -508,6 +542,15 @@ GridPtr OgreScene::CreateGridImpl(unsigned int _id, const std::string &_name)
   return (result) ? grid: nullptr;
 }
 
+//////////////////////////////////////////////////
+WireBoxPtr OgreScene::CreateWireBoxImpl(unsigned int _id,
+                                      const std::string &_name)
+{
+  OgreWireBoxPtr wireBox(new OgreWireBox);
+  bool result = this->InitObject(wireBox, _id, _name);
+  return (result) ? wireBox: nullptr;
+}
+
 //////////////////////////////////////////////////
 MarkerPtr OgreScene::CreateMarkerImpl(unsigned int _id,
                                       const std::string &_name)
@@ -517,6 +560,15 @@ MarkerPtr OgreScene::CreateMarkerImpl(unsigned int _id,
   return (result) ? marker: nullptr;
 }
 
+//////////////////////////////////////////////////
+LidarVisualPtr OgreScene::CreateLidarVisualImpl(unsigned int _id,
+                                      const std::string &_name)
+{
+  OgreLidarVisualPtr lidar(new OgreLidarVisual);
+  bool result = this->InitObject(lidar, _id, _name);
+  return (result) ? lidar: nullptr;
+}
+
 //////////////////////////////////////////////////
 TextPtr OgreScene::CreateTextImpl(unsigned int _id, const std::string &_name)
 {
@@ -561,6 +613,15 @@ RayQueryPtr OgreScene::CreateRayQueryImpl(unsigned int _id,
   return (result) ? rayQuery : nullptr;
 }
 
+//////////////////////////////////////////////////
+ParticleEmitterPtr OgreScene::CreateParticleEmitterImpl(unsigned int _id,
+    const std::string &_name)
+{
+  OgreParticleEmitterPtr visual(new OgreParticleEmitter);
+  bool result = this->InitObject(visual, _id, _name);
+  return (result) ? visual : nullptr;
+}
+
 //////////////////////////////////////////////////
 bool OgreScene::InitObject(OgreObjectPtr _object, unsigned int _id,
     const std::string &_name)
