@@ -15,20 +15,34 @@
  *
  */
 
-#include "gz/rendering/ogre2/Ogre2Camera.hh"
-#include "gz/rendering/ogre2/Ogre2Conversions.hh"
-#include "gz/rendering/ogre2/Ogre2Includes.hh"
-// #include "gz/rendering/ogre2/Ogre2Material.hh"
-#include "gz/rendering/ogre2/Ogre2RenderTarget.hh"
-#include "gz/rendering/ogre2/Ogre2Scene.hh"
-#include "gz/rendering/ogre2/Ogre2SelectionBuffer.hh"
-#include "gz/rendering/Utils.hh"
+#include "ignition/rendering/ogre2/Ogre2Camera.hh"
+#include "ignition/rendering/ogre2/Ogre2Conversions.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderTarget.hh"
+#include "ignition/rendering/ogre2/Ogre2Scene.hh"
+#include "ignition/rendering/ogre2/Ogre2SelectionBuffer.hh"
+#include "ignition/rendering/Utils.hh"
 
-using namespace gz;
+#ifdef _MSC_VER
+  #pragma warning(push, 0)
+#endif
+#include <OgreCamera.h>
+#include <OgreItem.h>
+#include <OgreSceneManager.h>
+#ifdef _MSC_VER
+  #pragma warning(pop)
+#endif
+
+/// \brief Private data for the Ogre2Camera class
+class ignition::rendering::Ogre2CameraPrivate
+{
+};
+
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
 Ogre2Camera::Ogre2Camera()
+  : dataPtr(std::make_unique<Ogre2CameraPrivate>())
 {
 }
 
@@ -104,6 +118,18 @@ void Ogre2Camera::SetBackgroundColor(const math::Color &_color)
   this->renderTexture->SetBackgroundColor(_color);
 }
 
+//////////////////////////////////////////////////
+MaterialPtr Ogre2Camera::BackgroundMaterial() const
+{
+  return this->renderTexture->BackgroundMaterial();
+}
+
+//////////////////////////////////////////////////
+void Ogre2Camera::SetBackgroundMaterial(MaterialPtr _material)
+{
+  this->renderTexture->SetBackgroundMaterial(_material);
+}
+
 //////////////////////////////////////////////////
 void Ogre2Camera::SetMaterial(const MaterialPtr &_material)
 {
@@ -163,6 +189,7 @@ void Ogre2Camera::CreateRenderTexture()
   this->renderTexture->SetWidth(this->ImageWidth());
   this->renderTexture->SetHeight(this->ImageHeight());
   this->renderTexture->SetBackgroundColor(this->scene->BackgroundColor());
+  this->renderTexture->SetVisibilityMask(this->visibilityMask);
 }
 
 //////////////////////////////////////////////////
@@ -180,6 +207,19 @@ unsigned int Ogre2Camera::RenderTextureGLId() const
   return rt->GLId();
 }
 
+//////////////////////////////////////////////////
+void Ogre2Camera::SetShadowsNodeDefDirty()
+{
+  if (!this->renderTexture)
+    return;
+
+  Ogre2RenderTexturePtr rt =
+      std::dynamic_pointer_cast<Ogre2RenderTexture>(this->renderTexture);
+
+  if (rt)
+    rt->SetShadowsNodeDefDirty();
+}
+
 //////////////////////////////////////////////////
 void Ogre2Camera::SetSelectionBuffer()
 {
@@ -187,7 +227,13 @@ void Ogre2Camera::SetSelectionBuffer()
 }
 
 //////////////////////////////////////////////////
-VisualPtr Ogre2Camera::VisualAt(const math::Vector2i &_mousePos)
+Ogre2SelectionBuffer *Ogre2Camera::SelectionBuffer() const
+{
+  return this->selectionBuffer;
+}
+
+//////////////////////////////////////////////////
+VisualPtr Ogre2Camera::VisualAt(const ignition::math::Vector2i &_mousePos)
 {
   VisualPtr result;
 
@@ -202,7 +248,7 @@ VisualPtr Ogre2Camera::VisualAt(const math::Vector2i &_mousePos)
   }
 
   float ratio = screenScalingFactor();
-  math::Vector2i mousePos(
+  ignition::math::Vector2i mousePos(
       static_cast<int>(std::rint(ratio * _mousePos.X())),
       static_cast<int>(std::rint(ratio * _mousePos.Y())));
 
@@ -233,17 +279,8 @@ VisualPtr Ogre2Camera::VisualAt(const math::Vector2i &_mousePos)
 //////////////////////////////////////////////////
 RenderWindowPtr Ogre2Camera::CreateRenderWindow()
 {
-  RenderWindowPtr base = this->scene->CreateRenderWindow();
-  Ogre2RenderWindowPtr renderWindow =
-      std::dynamic_pointer_cast<Ogre2RenderWindow>(base);
-  renderWindow->SetWidth(this->ImageWidth());
-  renderWindow->SetHeight(this->ImageHeight());
-  renderWindow->SetDevicePixelRatio(1);
-  renderWindow->SetCamera(this->ogreCamera);
-  renderWindow->SetBackgroundColor(this->scene->BackgroundColor());
-
-  this->renderTexture = renderWindow;
-  return base;
+  // TODO(anyone)
+  return RenderWindowPtr();
 }
 
 //////////////////////////////////////////////////
@@ -277,3 +314,11 @@ Ogre::Camera *Ogre2Camera::OgreCamera() const
 {
   return ogreCamera;
 }
+
+//////////////////////////////////////////////////
+void Ogre2Camera::SetVisibilityMask(uint32_t _mask)
+{
+  BaseSensor::SetVisibilityMask(_mask);
+  if (this->renderTexture)
+    this->renderTexture->SetVisibilityMask(_mask);
+}
