@@ -15,31 +15,53 @@
  *
  */
 
-#include <gz/common/Console.hh>
-#include <gz/common/Mesh.hh>
-#include <gz/common/MeshManager.hh>
-#include <gz/common/SubMesh.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Mesh.hh>
+#include <ignition/common/MeshManager.hh>
+#include <ignition/common/SubMesh.hh>
 
-#include "gz/rendering/ogre2/Ogre2Includes.hh"
-#include "gz/rendering/ogre2/Ogre2Camera.hh"
-#include "gz/rendering/ogre2/Ogre2Conversions.hh"
-#include "gz/rendering/ogre2/Ogre2RayQuery.hh"
-#include "gz/rendering/ogre2/Ogre2Scene.hh"
+#include "ignition/rendering/ogre2/Ogre2Camera.hh"
+#include "ignition/rendering/ogre2/Ogre2Conversions.hh"
+#include "ignition/rendering/ogre2/Ogre2RayQuery.hh"
+#include "ignition/rendering/ogre2/Ogre2Scene.hh"
+#include "ignition/rendering/ogre2/Ogre2SelectionBuffer.hh"
+
+#ifdef _MSC_VER
+  #pragma warning(push, 0)
+#endif
+#include <OgreCamera.h>
+#include <OgreItem.h>
+#include <OgreMesh2.h>
+#include <OgreRay.h>
+#include <OgreSceneManager.h>
+#ifdef _MSC_VER
+  #pragma warning(pop)
+#endif
 
 /// \brief Private data class for Ogre2RayQuery
-class gz::rendering::Ogre2RayQueryPrivate
+class ignition::rendering::Ogre2RayQueryPrivate
 {
   /// \brief Ogre ray scene query object for computing intersection.
   public: Ogre::RaySceneQuery *rayQuery = nullptr;
+
+  //// \brief Pointer to camera
+  public: Ogre2CameraPtr camera{nullptr};
+
+  /// \brief Image pos to cast the ray from
+  public: math::Vector2i imgPos = math::Vector2i::Zero;
+
+  /// \brief thread that ray query is created in
+  public: std::thread::id threadId;
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
 Ogre2RayQuery::Ogre2RayQuery()
     : dataPtr(new Ogre2RayQueryPrivate)
 {
+  this->dataPtr->threadId = std::this_thread::get_id();
 }
 
 //////////////////////////////////////////////////
@@ -59,10 +81,77 @@ void Ogre2RayQuery::SetFromCamera(const CameraPtr &_camera,
 
   this->origin = Ogre2Conversions::Convert(ray.getOrigin());
   this->direction = Ogre2Conversions::Convert(ray.getDirection());
+
+  this->dataPtr->camera = camera;
+
+  this->dataPtr->imgPos.X() = static_cast<int>(
+      screenPos.X() * this->dataPtr->camera->ImageWidth());
+  this->dataPtr->imgPos.Y() = static_cast<int>(
+      screenPos.Y() * this->dataPtr->camera->ImageHeight());
 }
 
 //////////////////////////////////////////////////
 RayQueryResult Ogre2RayQuery::ClosestPoint()
+{
+  RayQueryResult result;
+
+#ifdef __APPLE__
+  return this->ClosestPointByIntersection();
+#else
+  if (!this->dataPtr->camera ||
+      !this->dataPtr->camera->Parent() ||
+      std::this_thread::get_id() != this->dataPtr->threadId)
+  {
+    // use legacy method for backward compatibility if no camera is set or
+    // camera is not attached in the scene tree or
+    // this function is called from non-rendering thread
+    return this->ClosestPointByIntersection();
+  }
+  else
+  {
+    // the VisualAt function is a hack to force creation of the selection
+    // buffer object
+    // todo(anyone) Make Camera::SetSelectionBuffer function public?
+    if (!this->dataPtr->camera->SelectionBuffer())
+      this->dataPtr->camera->VisualAt(math::Vector2i(0, 0));
+
+    return this->ClosestPointBySelectionBuffer();
+  }
+#endif
+}
+
+//////////////////////////////////////////////////
+RayQueryResult Ogre2RayQuery::ClosestPointBySelectionBuffer()
+{
+  RayQueryResult result;
+  Ogre::Item *ogreItem = nullptr;
+  math::Vector3d point;
+  bool success = this->dataPtr->camera->SelectionBuffer()->ExecuteQuery(
+      this->dataPtr->imgPos.X(), this->dataPtr->imgPos.Y(), ogreItem, point);
+  result.distance = -1;
+
+  if (success && ogreItem)
+  {
+    if (!ogreItem->getUserObjectBindings().getUserAny().isEmpty() &&
+        ogreItem->getUserObjectBindings().getUserAny().getType() ==
+        typeid(unsigned int))
+    {
+      auto userAny = ogreItem->getUserObjectBindings().getUserAny();
+      double distance = this->dataPtr->camera->WorldPosition().Distance(point)
+          - this->dataPtr->camera->NearClipPlane();
+      if (!std::isinf(distance))
+      {
+        result.distance = distance;
+        result.point = point;
+        result.objectId = Ogre::any_cast<unsigned int>(userAny);
+      }
+    }
+  }
+  return result;
+}
+
+//////////////////////////////////////////////////
+RayQueryResult Ogre2RayQuery::ClosestPointByIntersection()
 {
   RayQueryResult result;
   Ogre2ScenePtr ogreScene =
@@ -130,11 +219,11 @@ RayQueryResult Ogre2RayQuery::ClosestPoint()
           if (indexCount <= k+2)
             continue;
 
-          math::Vector3d vertexA =
+          ignition::math::Vector3d vertexA =
             submesh->Vertex(submesh->Index(k));
-          math::Vector3d vertexB =
+          ignition::math::Vector3d vertexB =
             submesh->Vertex(submesh->Index(k+1));
-          math::Vector3d vertexC =
+          ignition::math::Vector3d vertexC =
             submesh->Vertex(submesh->Index(k+2));
 
           Ogre::Vector3 worldVertexA =
