@@ -15,9 +15,18 @@
  *
  */
 
-#include "gz/rendering/ogre2/Ogre2RenderTargetMaterial.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderTargetMaterial.hh"
 
-using namespace gz::rendering;
+#ifdef _MSC_VER
+  #pragma warning(push, 0)
+#endif
+#include <OgreRenderTarget.h>
+#include <OgreViewport.h>
+#ifdef _MSC_VER
+  #pragma warning(pop)
+#endif
+
+using namespace ignition::rendering;
 
 
 //////////////////////////////////////////////////
@@ -66,3 +75,10 @@ Ogre::Technique *Ogre2RenderTargetMaterial::handleSchemeNotFound(
   }
   return nullptr;
 }
+
+//////////////////////////////////////////////////
+bool Ogre2RenderTargetMaterial::IsSameRenderTarget(
+    Ogre::RenderTarget *_renderTarget)
+{
+  return this->renderTarget == _renderTarget;
+}
