@@ -17,17 +17,17 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
-#include "gz/rendering/Camera.hh"
-#include "gz/rendering/GaussianNoisePass.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/RenderPassSystem.hh"
-#include "gz/rendering/Scene.hh"
+#include "ignition/rendering/Camera.hh"
+#include "ignition/rendering/GaussianNoisePass.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/RenderPassSystem.hh"
+#include "ignition/rendering/Scene.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class CameraTest : public testing::Test,
@@ -44,6 +44,9 @@ class CameraTest : public testing::Test,
 
   /// \brief Test adding and removing render passes
   public: void AddRemoveRenderPass(const std::string &_renderEngine);
+
+  /// \brief Test setting visibility mask
+  public: void VisibilityMask(const std::string &_renderEngine);
 };
 
 /////////////////////////////////////////////////
@@ -104,7 +107,7 @@ void CameraTest::ViewProjectionMatrix(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -149,7 +152,7 @@ void CameraTest::RenderTexture(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -221,7 +224,7 @@ void CameraTest::TrackFollow(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -275,7 +278,40 @@ void CameraTest::AddRemoveRenderPass(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
+}
+
+/////////////////////////////////////////////////
+void CameraTest::VisibilityMask(const std::string &_renderEngine)
+{
+  // create and populate scene
+  RenderEngine *engine = rendering::engine(_renderEngine);
+  if (!engine)
+  {
+    igndbg << "Engine '" << _renderEngine
+              << "' is not supported" << std::endl;
+    return;
+  }
+  ScenePtr scene = engine->CreateScene("scene");
+  ASSERT_NE(nullptr, scene);
+
+  CameraPtr camera = scene->CreateCamera();
+  EXPECT_TRUE(camera != nullptr);
+
+  // chek initial value
+  EXPECT_EQ(static_cast<uint32_t>(IGN_VISIBILITY_ALL),
+      camera->VisibilityMask());
+
+  // check setting new values
+  camera->SetVisibilityMask(0x00000010u);
+  EXPECT_EQ(0x00000010u, camera->VisibilityMask());
+
+  camera->SetVisibilityMask(0u);
+  EXPECT_EQ(0u, camera->VisibilityMask());
+
+  // Clean up
+  engine->DestroyScene(scene);
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -302,9 +338,15 @@ TEST_P(CameraTest, AddRemoveRenderPass)
   AddRemoveRenderPass(GetParam());
 }
 
+/////////////////////////////////////////////////
+TEST_P(CameraTest, VisibilityMask)
+{
+  VisibilityMask(GetParam());
+}
+
 INSTANTIATE_TEST_CASE_P(Camera, CameraTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
