@@ -18,15 +18,15 @@
 #include <map>
 #include <mutex>
 
-#include <gz/common/Console.hh>
-#include <gz/common/SystemPaths.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/SystemPaths.hh>
 
-#include <gz/plugin/Loader.hh>
+#include <ignition/plugin/Loader.hh>
 
-#include "gz/rendering/config.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderEngineManager.hh"
-#include "gz/rendering/RenderEnginePlugin.hh"
+#include "ignition/rendering/config.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderEngineManager.hh"
+#include "ignition/rendering/RenderEnginePlugin.hh"
 
 /// \brief Holds information about an engine
 struct EngineInfo
@@ -36,11 +36,11 @@ struct EngineInfo
   std::string name;
 
   /// \brief The pointer to the render engine.
-  gz::rendering::RenderEngine *engine;
+  ignition::rendering::RenderEngine *engine;
 };
 
 /// \brief Private implementation of the RenderEngineManager class.
-class gz::rendering::RenderEngineManagerPrivate
+class ignition::rendering::RenderEngineManagerPrivate
 {
   /// \brief EngineMap that maps engine name to an engine pointer.
   typedef std::map<std::string, RenderEngine *> EngineMap;
@@ -93,7 +93,10 @@ class gz::rendering::RenderEngineManagerPrivate
   public: std::map<std::string, std::string> enginePlugins;
 
   /// \brief Plugin loader for managing render engine plugin libraries.
-  public: gz::plugin::Loader pluginLoader;
+  public: ignition::plugin::Loader pluginLoader;
+
+  /// \brief Environment variable which holds paths to look for plugins
+  public: std::string pluginPathEnv = "IGN_RENDERING_PLUGIN_PATH";
 
   /// \brief List which holds paths to look for engine plugins.
   public: std::list<std::string> pluginPaths;
@@ -102,7 +105,7 @@ class gz::rendering::RenderEngineManagerPrivate
   public: std::recursive_mutex enginesMutex;
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -204,8 +207,6 @@ RenderEngine *RenderEngineManager::Engine(const std::string &_name,
   EngineInfo info{_name, nullptr};
   std::lock_guard<std::recursive_mutex> lock(this->dataPtr->enginesMutex);
   // check in the list of available engines
-
-  // Check in the list of registered engines
   auto iter = this->dataPtr->engines.find(_name);
   if (iter != this->dataPtr->engines.end())
   {
@@ -440,7 +441,8 @@ bool RenderEngineManagerPrivate::LoadEnginePlugin(
 {
   ignmsg << "Loading plugin [" << _filename << "]" << std::endl;
 
-  common::SystemPaths systemPaths;
+  ignition::common::SystemPaths systemPaths;
+  systemPaths.SetPluginPathEnv(this->pluginPathEnv);
 
   // Add default install folder.
   systemPaths.AddPluginPaths(std::string(IGN_RENDERING_PLUGIN_PATH));
@@ -472,7 +474,7 @@ bool RenderEngineManagerPrivate::LoadEnginePlugin(
   }
 
   auto engineNames = pluginLoader.PluginsImplementing<
-      rendering::RenderEnginePlugin>();
+      ignition::rendering::RenderEnginePlugin>();
 
   if (engineNames.empty())
   {
@@ -512,7 +514,7 @@ bool RenderEngineManagerPrivate::LoadEnginePlugin(
   }
 
   auto renderPlugin =
-      plugin->QueryInterface<rendering::RenderEnginePlugin>();
+      plugin->QueryInterface<ignition::rendering::RenderEnginePlugin>();
 
   if (!renderPlugin)
   {
