@@ -18,17 +18,18 @@
 #include <gtest/gtest.h>
 #include <string>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/math/AxisAlignedBox.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "gz/rendering/Geometry.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/Scene.hh"
-#include "gz/rendering/Visual.hh"
+#include "ignition/rendering/Geometry.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/Scene.hh"
+#include "ignition/rendering/Visual.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class VisualTest : public testing::Test,
@@ -48,6 +49,12 @@ class VisualTest : public testing::Test,
 
   /// \brief Test adding removing geometry
   public: void Geometry(const std::string &_renderEngine);
+
+  /// \brief Test setting visibility flags
+  public: void VisibilityFlags(const std::string &_renderEngine);
+
+  /// \brief Test getting setting bounding boxes
+  public: void BoundingBox(const std::string &_renderEngine);
 };
 
 /////////////////////////////////////////////////
@@ -126,7 +133,7 @@ void VisualTest::Material(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -195,7 +202,7 @@ void VisualTest::Children(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -286,7 +293,7 @@ void VisualTest::Scale(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -349,7 +356,7 @@ void VisualTest::UserData(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -424,7 +431,7 @@ void VisualTest::Geometry(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -433,9 +440,118 @@ TEST_P(VisualTest, Geometry)
   Geometry(GetParam());
 }
 
+/////////////////////////////////////////////////
+void VisualTest::VisibilityFlags(const std::string &_renderEngine)
+{
+  RenderEngine *engine = rendering::engine(_renderEngine);
+  if (!engine)
+  {
+    igndbg << "Engine '" << _renderEngine
+              << "' is not supported" << std::endl;
+    return;
+  }
+
+  ScenePtr scene = engine->CreateScene("scene5");
+
+  // create visual
+  VisualPtr visual = scene->CreateVisual();
+  ASSERT_NE(nullptr, visual);
+
+  // check initial value
+  EXPECT_EQ(static_cast<uint32_t>(IGN_VISIBILITY_ALL),
+      visual->VisibilityFlags());
+
+  // check setting new values
+  visual->SetVisibilityFlags(0x00000001u);
+  EXPECT_EQ(0x00000001u, visual->VisibilityFlags());
+
+  visual->AddVisibilityFlags(0x10000000u);
+  EXPECT_EQ(0x10000001u, visual->VisibilityFlags());
+
+  visual->RemoveVisibilityFlags(0x00000001u);
+  EXPECT_EQ(0x10000000u, visual->VisibilityFlags());
+
+  VisualPtr visual2 = scene->CreateVisual();
+  ASSERT_NE(nullptr, visual2);
+  EXPECT_EQ(static_cast<uint32_t>(IGN_VISIBILITY_ALL),
+      visual2->VisibilityFlags());
+
+  // check setting visibility flags to visual with child nodes
+  visual->AddChild(visual2);
+
+  visual->SetVisibilityFlags(0x00000001u);
+  EXPECT_EQ(0x00000001u, visual->VisibilityFlags());
+  EXPECT_EQ(0x00000001u, visual2->VisibilityFlags());
+
+  visual->AddVisibilityFlags(0x01000000u);
+  EXPECT_EQ(0x01000001u, visual->VisibilityFlags());
+  EXPECT_EQ(0x01000001u, visual2->VisibilityFlags());
+
+  visual->RemoveVisibilityFlags(0x00000001u);
+  EXPECT_EQ(0x01000000u, visual->VisibilityFlags());
+  EXPECT_EQ(0x01000000u, visual2->VisibilityFlags());
+
+  // set child node's visibility flag only
+  visual2->SetVisibilityFlags(0x00000010u);
+  EXPECT_EQ(0x01000000u, visual->VisibilityFlags());
+  EXPECT_EQ(0x00000010u, visual2->VisibilityFlags());
+
+  // Clean up
+  engine->DestroyScene(scene);
+  rendering::unloadEngine(engine->Name());
+}
+
+/////////////////////////////////////////////////
+TEST_P(VisualTest, VisibilityFlags)
+{
+  VisibilityFlags(GetParam());
+}
+
+/////////////////////////////////////////////////
+void VisualTest::BoundingBox(const std::string &_renderEngine)
+{
+  RenderEngine *engine = rendering::engine(_renderEngine);
+  if (!engine)
+  {
+    igndbg << "Engine '" << _renderEngine
+              << "' is not supported" << std::endl;
+    return;
+  }
+
+  ScenePtr scene = engine->CreateScene("scene6");
+
+  // create visual
+  VisualPtr visual = scene->CreateVisual();
+  ASSERT_NE(nullptr, visual);
+
+  // Add geometries
+  GeometryPtr box = scene->CreateBox();
+  visual->AddGeometry(box);
+  visual->SetWorldPosition(1.0, 2.0, 3.0);
+
+  ignition::math::AxisAlignedBox localBoundingBox = visual->LocalBoundingBox();
+  ignition::math::AxisAlignedBox boundingBox = visual->BoundingBox();
+
+  EXPECT_EQ(ignition::math::Vector3d(-0.5, -0.5, -0.5), localBoundingBox.Min());
+  EXPECT_EQ(ignition::math::Vector3d(0.5, 0.5, 0.5), localBoundingBox.Max());
+  EXPECT_EQ(ignition::math::Vector3d(0.5, 1.5, 2.5), boundingBox.Min());
+  EXPECT_EQ(ignition::math::Vector3d(1.5, 2.5, 3.5), boundingBox.Max());
+
+  // Clean up
+  engine->DestroyScene(scene);
+  rendering::unloadEngine(engine->Name());
+}
+
+/////////////////////////////////////////////////
+TEST_P(VisualTest, BoundingBox)
+{
+  BoundingBox(GetParam());
+}
+
+
 INSTANTIATE_TEST_CASE_P(Visual, VisualTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
