@@ -17,39 +17,48 @@
 
 #include <sstream>
 
-#include <gz/math/Helpers.hh>
+#include <ignition/math/Helpers.hh>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Mesh.hh>
-#include <gz/common/MeshManager.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Mesh.hh>
+#include <ignition/common/MeshManager.hh>
 
-#include "gz/common/Time.hh"
+#include "ignition/common/Time.hh"
 
-#include "gz/rendering/ArrowVisual.hh"
-#include "gz/rendering/AxisVisual.hh"
-#include "gz/rendering/Camera.hh"
-#include "gz/rendering/DepthCamera.hh"
-#include "gz/rendering/GizmoVisual.hh"
-#include "gz/rendering/GpuRays.hh"
-#include "gz/rendering/Grid.hh"
-#include "gz/rendering/RayQuery.hh"
-#include "gz/rendering/RenderTarget.hh"
-#include "gz/rendering/Text.hh"
-#include "gz/rendering/ThermalCamera.hh"
-#include "gz/rendering/Visual.hh"
-#include "gz/rendering/base/BaseStorage.hh"
-#include "gz/rendering/base/BaseScene.hh"
+#include "ignition/rendering/ArrowVisual.hh"
+#include "ignition/rendering/AxisVisual.hh"
+#include "ignition/rendering/LidarVisual.hh"
+#include "ignition/rendering/LightVisual.hh"
+#include "ignition/rendering/Camera.hh"
+#include "ignition/rendering/Capsule.hh"
+#include "ignition/rendering/DepthCamera.hh"
+#include "ignition/rendering/GizmoVisual.hh"
+#include "ignition/rendering/GpuRays.hh"
+#include "ignition/rendering/Grid.hh"
+#include "ignition/rendering/ParticleEmitter.hh"
+#include "ignition/rendering/RayQuery.hh"
+#include "ignition/rendering/RenderTarget.hh"
+#include "ignition/rendering/Text.hh"
+#include "ignition/rendering/ThermalCamera.hh"
+#include "ignition/rendering/Visual.hh"
+#include "ignition/rendering/base/BaseStorage.hh"
+#include "ignition/rendering/base/BaseScene.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
+// Prevent deprecation warnings for simTime
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
 //////////////////////////////////////////////////
 BaseScene::BaseScene(unsigned int _id, const std::string &_name) :
   id(_id),
   name(_name),
   loaded(false),
   initialized(false),
-  nextObjectId(math::MAX_UI16),
+  nextObjectId(ignition::math::MAX_UI16),
   nodes(nullptr)
 {
 }
@@ -58,6 +67,9 @@ BaseScene::BaseScene(unsigned int _id, const std::string &_name) :
 BaseScene::~BaseScene()
 {
 }
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
 
 //////////////////////////////////////////////////
 void BaseScene::Load()
@@ -116,20 +128,39 @@ std::string BaseScene::Name() const
 }
 
 //////////////////////////////////////////////////
+std::chrono::steady_clock::duration BaseScene::Time() const
+{
+  return this->time;
+}
+
+//////////////////////////////////////////////////
+void BaseScene::SetTime(const std::chrono::steady_clock::duration &_time)
+{
+  this->time = _time;
+}
+
+//////////////////////////////////////////////////
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
 common::Time BaseScene::SimTime() const
 {
   return this->simTime;
 }
 
-//////////////////////////////////////////////////
+////////////////////////////////////////////////////
 void BaseScene::SetSimTime(const common::Time &_time)
 {
   this->simTime = _time;
 }
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
 
 //////////////////////////////////////////////////
 VisualPtr BaseScene::VisualAt(const CameraPtr &_camera,
-                              const math::Vector2i &_mousePos)
+                              const ignition::math::Vector2i &_mousePos)
 {
   VisualPtr visual;
   RayQueryPtr rayQuery = this->CreateRayQuery();
@@ -208,6 +239,18 @@ void BaseScene::RemoveGradientBackgroundColor()
   this->isGradientBackgroundColor = false;
 }
 
+//////////////////////////////////////////////////
+MaterialPtr BaseScene::BackgroundMaterial() const
+{
+  return this->backgroundMaterial;
+}
+
+//////////////////////////////////////////////////
+void BaseScene::SetBackgroundMaterial(MaterialPtr _material)
+{
+  this->backgroundMaterial = _material;
+}
+
 //////////////////////////////////////////////////
 unsigned int BaseScene::NodeCount() const
 {
@@ -875,6 +918,36 @@ AxisVisualPtr BaseScene::CreateAxisVisual(unsigned int _id,
   return (result) ? visual : nullptr;
 }
 
+//////////////////////////////////////////////////
+LightVisualPtr BaseScene::CreateLightVisual()
+{
+  unsigned int objId = this->CreateObjectId();
+  return this->CreateLightVisual(objId);
+}
+
+//////////////////////////////////////////////////
+LightVisualPtr BaseScene::CreateLightVisual(unsigned int _id)
+{
+  std::string objName = this->CreateObjectName(_id, "LightVisual");
+  return this->CreateLightVisual(_id, objName);
+}
+
+//////////////////////////////////////////////////
+LightVisualPtr BaseScene::CreateLightVisual(const std::string &_name)
+{
+  unsigned int objId = this->CreateObjectId();
+  return this->CreateLightVisual(objId, _name);
+}
+
+//////////////////////////////////////////////////
+LightVisualPtr BaseScene::CreateLightVisual(unsigned int _id,
+    const std::string &_name)
+{
+  LightVisualPtr visual = this->CreateLightVisualImpl(_id, _name);
+  bool result = this->RegisterVisual(visual);
+  return (result) ? visual : nullptr;
+}
+
 //////////////////////////////////////////////////
 GizmoVisualPtr BaseScene::CreateGizmoVisual()
 {
@@ -937,6 +1010,14 @@ GeometryPtr BaseScene::CreatePlane()
   return this->CreatePlaneImpl(objId, objName);
 }
 
+//////////////////////////////////////////////////
+CapsulePtr BaseScene::CreateCapsule()
+{
+  unsigned int objId = this->CreateObjectId();
+  std::string objName = this->CreateObjectName(objId, "Capsule");
+  return this->CreateCapsuleImpl(objId, objName);
+}
+
 //////////////////////////////////////////////////
 GeometryPtr BaseScene::CreateSphere()
 {
@@ -970,6 +1051,14 @@ MeshPtr BaseScene::CreateMesh(const MeshDescriptor &_desc)
   return this->CreateMeshImpl(objId, objName, _desc);
 }
 
+//////////////////////////////////////////////////
+HeightmapPtr BaseScene::CreateHeightmap(const HeightmapDescriptor &_desc)
+{
+  unsigned int objId = this->CreateObjectId();
+  std::string objName = this->CreateObjectName(objId, "Heightmap");
+  return this->CreateHeightmapImpl(objId, objName, _desc);
+}
+
 //////////////////////////////////////////////////
 GridPtr BaseScene::CreateGrid()
 {
@@ -986,6 +1075,44 @@ MarkerPtr BaseScene::CreateMarker()
   return this->CreateMarkerImpl(objId, objName);
 }
 
+//////////////////////////////////////////////////
+LidarVisualPtr BaseScene::CreateLidarVisual()
+{
+  unsigned int objId = this->CreateObjectId();
+  return this->CreateLidarVisual(objId);
+}
+
+//////////////////////////////////////////////////
+LidarVisualPtr BaseScene::CreateLidarVisual(unsigned int _id)
+{
+  const std::string objName = this->CreateObjectName(_id, "LidarVisual");
+  return this->CreateLidarVisual(_id, objName);
+}
+
+//////////////////////////////////////////////////
+LidarVisualPtr BaseScene::CreateLidarVisual(const std::string &_name)
+{
+  unsigned int objId = this->CreateObjectId();
+  return this->CreateLidarVisual(objId, _name);
+}
+
+//////////////////////////////////////////////////
+LidarVisualPtr BaseScene::CreateLidarVisual(unsigned int _id,
+                                            const std::string &_name)
+{
+  LidarVisualPtr lidar = this->CreateLidarVisualImpl(_id, _name);
+  bool result = this->RegisterVisual(lidar);
+  return (result) ? lidar : nullptr;
+}
+
+//////////////////////////////////////////////////
+WireBoxPtr BaseScene::CreateWireBox()
+{
+  unsigned int objId = this->CreateObjectId();
+  std::string objName = this->CreateObjectName(objId, "Wirebox");
+  return this->CreateWireBoxImpl(objId, objName);
+}
+
 //////////////////////////////////////////////////
 TextPtr BaseScene::CreateText()
 {
@@ -1054,6 +1181,54 @@ RayQueryPtr BaseScene::CreateRayQuery()
   return this->CreateRayQueryImpl(objId, objName);
 }
 
+//////////////////////////////////////////////////
+ParticleEmitterPtr BaseScene::CreateParticleEmitter()
+{
+  unsigned int objId = this->CreateObjectId();
+  return this->CreateParticleEmitter(objId);
+}
+
+//////////////////////////////////////////////////
+ParticleEmitterPtr BaseScene::CreateParticleEmitter(unsigned int _id)
+{
+  std::string objName = this->CreateObjectName(_id, "ParticleEmitter");
+  return this->CreateParticleEmitter(_id, objName);
+}
+
+//////////////////////////////////////////////////
+ParticleEmitterPtr BaseScene::CreateParticleEmitter(const std::string &_name)
+{
+  unsigned int objId = this->CreateObjectId();
+  return this->CreateParticleEmitter(objId, _name);
+}
+
+//////////////////////////////////////////////////
+ParticleEmitterPtr BaseScene::CreateParticleEmitter(unsigned int _id,
+    const std::string &_name)
+{
+  ParticleEmitterPtr visual = this->CreateParticleEmitterImpl(_id, _name);
+  bool result = this->RegisterVisual(visual);
+  return (result) ? visual : nullptr;
+}
+
+//////////////////////////////////////////////////
+void BaseScene::SetSkyEnabled(bool _enabled)  // NOLINT(readability/casting)
+{
+  // no op, let derived class implement this.
+  if (_enabled)
+  {
+    ignerr << "Sky not supported by: "
+           << this->Engine()->Name() << std::endl;
+  }
+}
+
+//////////////////////////////////////////////////
+bool BaseScene::SkyEnabled() const
+{
+  return false;
+}
+
+
 //////////////////////////////////////////////////
 void BaseScene::PreRender()
 {
@@ -1065,7 +1240,7 @@ void BaseScene::Clear()
 {
   this->nodes->DestroyAll();
   this->DestroyMaterials();
-  this->nextObjectId = math::MAX_UI16;
+  this->nextObjectId = ignition::math::MAX_UI16;
 }
 
 //////////////////////////////////////////////////
